@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Sender::Util;
 # ABSTRACT: random stuff that makes Email::Sender go
-$Email::Sender::Util::VERSION = '1.300030';
+$Email::Sender::Util::VERSION = '1.300031';
 use Email::Address;
 use Email::Sender::Failure;
 use Email::Sender::Failure::Permanent;
@@ -80,12 +80,19 @@ sub _failure {
 #pod
 #pod =cut
 
+sub _rewrite_class {
+  my $transport_class = $_[1];
+  if ($transport_class !~ s/^=// and $transport_class !~ m{:}) {
+    $transport_class = "Email::Sender::Transport::$transport_class";
+  }
+
+  return $transport_class;
+}
+
 sub easy_transport {
   my ($self, $transport_class, $arg) = @_;
 
-  if ($transport_class =~ s/^=// or $transport_class !~ tr/://) {
-    $transport_class = "Email::Sender::Transport::$transport_class";
-  }
+  $transport_class = $self->_rewrite_class($transport_class);
 
   require_module($transport_class);
   return $transport_class->new($arg);
@@ -105,7 +112,7 @@ Email::Sender::Util - random stuff that makes Email::Sender go
 
 =head1 VERSION
 
-version 1.300030
+version 1.300031
 
 =head1 METHODS
 
@@ -126,7 +133,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2017 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
